@@ -32,7 +32,7 @@ extern "C" {
  * 0.2.6-1 => 0x00020601
  * 4.5.2-0 => 0x04050200
  */
-#define EXTRACTOR_VERSION 0x00051600
+#define EXTRACTOR_VERSION 0x00051801
 
 #include <stdio.h>
 
@@ -143,9 +143,9 @@ typedef enum {
   EXTRACTOR_ORIENTATION = 87,
   EXTRACTOR_TEMPLATE = 88,
   EXTRACTOR_SPLIT = 89,
-  EXTRACTOR_PRODUCTVERSION = 90,  
+  EXTRACTOR_PRODUCTVERSION = 90,
   EXTRACTOR_LAST_SAVED_BY = 91,
-  EXTRACTOR_LAST_PRINTED = 92,  
+  EXTRACTOR_LAST_PRINTED = 92,
   EXTRACTOR_WORD_COUNT = 93,
   EXTRACTOR_CHARACTER_COUNT = 94,
   EXTRACTOR_TOTAL_EDITING_TIME = 95,
@@ -169,7 +169,6 @@ typedef enum {
   EXTRACTOR_FULL_NAME = 113,
   EXTRACTOR_CHAPTER = 114,
   EXTRACTOR_YEAR = 115,
-
   EXTRACTOR_LINK = 116,
   EXTRACTOR_MUSIC_CD_IDENTIFIER = 117,
   EXTRACTOR_PLAY_COUNTER = 118,
@@ -178,14 +177,14 @@ typedef enum {
   EXTRACTOR_ENCODED_BY = 121,
   EXTRACTOR_TIME = 122,
   EXTRACTOR_MUSICIAN_CREDITS_LIST = 123,
-  EXTRACTOR_MOOD = 124,
-
+  EXTRACTOR_MOOD = 124, 
   EXTRACTOR_FORMAT_VERSION = 125,
   EXTRACTOR_TELEVISION_SYSTEM = 126,
   EXTRACTOR_SONG_COUNT = 127,
   EXTRACTOR_STARTING_SONG = 128,
   EXTRACTOR_HARDWARE_DEPENDENCY = 129,
-
+  EXTRACTOR_RIPPER = 130,
+  EXTRACTOR_FILE_SIZE = 131
 } EXTRACTOR_KeywordType;
 
 /**
