@@ -132,6 +132,8 @@ printHelp ()
       gettext_noop("remove duplicates only if types match") },
     { 'f', "filename", NULL,
       gettext_noop("use the filename as a keyword (loads filename-extractor plugin)") },
+    { 'g', "grep-friendly", NULL,
+      gettext_noop("produce grep-friendly output (all results on one line per file)") },
     { 'h', "help", NULL,
       gettext_noop("print this help") },
     { 'H', "hash", "ALGORITHM",
@@ -167,7 +169,7 @@ printHelp ()
 
 /**
  * Print a keyword list to a file.
- * For debugging.
+ *
  * @param handle the file to write to (stdout, stderr), may NOT be NULL
  * @param keywords the list of keywords to print, may be NULL
  * @param print array indicating which types to print
@@ -180,24 +182,19 @@ printSelectedKeywords(FILE * handle,
 {
   char * keyword;
   iconv_t cd;
-  char * buf;
 
-  cd = iconv_open(
-    nl_langinfo(CODESET)
-    , "UTF-8");
+  cd = iconv_open(nl_langinfo(CODESET), "UTF-8");
   while (keywords != NULL) {
-    buf = NULL;
-    if (cd != (iconv_t) -1)
-      keyword = iconvHelper(cd,
-			    keywords->keyword);
-    else
-      keyword = strdup(keywords->keyword);
-
-    if (keywords->keywordType == EXTRACTOR_THUMBNAIL_DATA) {
+    if (EXTRACTOR_isBinaryType(keywords->keywordType)) {
       fprintf (handle,
 	       _("%s - (binary)\n"),
 	       _(EXTRACTOR_getKeywordTypeAsString(keywords->keywordType)));
     } else {
+      if (cd != (iconv_t) -1)
+	keyword = iconvHelper(cd,
+			      keywords->keyword);
+      else
+	keyword = strdup(keywords->keyword);
       if (NULL == EXTRACTOR_getKeywordTypeAsString(keywords->keywordType)) {
 	if (verbose == YES) {
 	  fprintf(handle,
@@ -209,28 +206,80 @@ printSelectedKeywords(FILE * handle,
 		 "%s - %s\n",
 		 _(EXTRACTOR_getKeywordTypeAsString(keywords->keywordType)),
 		 keyword);
+      free(keyword);
     }
-    free(keyword);
     keywords = keywords->next;
   }
   if (cd != (iconv_t) -1)
     iconv_close(cd);
 }
 
+/**
+ * Print a keyword list to a file in a grep-friendly manner.
+ *
+ * @param handle the file to write to (stdout, stderr), may NOT be NULL
+ * @param keywords the list of keywords to print, may be NULL
+ * @param print array indicating which types to print
+ */
+static void
+printSelectedKeywordsGrepFriendly(FILE * handle,
+				  EXTRACTOR_KeywordList * keywords,
+				  const int * print,
+				  const int verbose)
+{
+  char * keyword;
+  iconv_t cd;
+  size_t pos;
+
+  cd = iconv_open(nl_langinfo(CODESET), "UTF-8");
+  while (keywords != NULL) {
+    if ( (EXTRACTOR_isBinaryType(EXTRACTOR_THUMBNAIL_DATA)) &&
+	 (print[keywords->keywordType] == YES) ) {
+      if (verbose > 1) 
+	fprintf(handle,
+		"%s: ",
+		_(EXTRACTOR_getKeywordTypeAsString(keywords->keywordType)));
+      if (cd != (iconv_t) -1)
+	keyword = iconvHelper(cd,
+			      keywords->keyword);
+      else
+	keyword = strdup(keywords->keyword);
+      pos = 0;
+      while (keyword[pos] != '\0') {
+	if (iscntrl(keyword[pos]))	
+	  keyword[pos] = ' ';
+	pos++;
+      }
+      fprintf (handle,
+	       (keywords->next == NULL) ? "%s" : "%s ",
+	       keyword);
+      free(keyword);
+    }
+    keywords = keywords->next;
+  }
+  fprintf(handle, "\n");
+  if (cd != (iconv_t) -1)
+    iconv_close(cd);
+}
+
 /**
  * Take title, auth, year and return a string
  */
 static char *
 str_splice(const char * title,
-       const char * auth,
-       const char * year)
-{
-  char * temp = (char*)malloc(sizeof(char)*16);
+	   const char * auth,
+	   const char * year) {
+  char * temp = malloc(16);
   int i = 0;
-  memset(temp, 0, sizeof(char)*16);
-  snprintf(temp, 15, "%.5s%.5s%.5s", auth, year, title);
-  for ( i = 0; i < strlen(temp); i++ ) {
-    if ( !isalnum(temp[i]) )
+
+  snprintf(temp, 
+	   15,
+	   "%.5s%.5s%.5s", 
+	   auth, 
+	   year, 
+	   title);
+  for (i=0;i<strlen(temp);i++ ) {
+    if (! isalnum(temp[i]) )
       temp[i] = '_';
     else
       temp[i] = tolower(temp[i]);
@@ -266,6 +315,7 @@ printSelectedKeywordsBibtex (FILE * handle,
       const char * pages = NULL;
       char * year = NULL;
       char * month = NULL;
+      char * tmp;
 
       title = EXTRACTOR_extractLastByString(_("title"), keywords);
       if ( !title )
@@ -332,7 +382,11 @@ printSelectedKeywordsBibtex (FILE * handle,
       if ( pages )
 	last = pages;
 
-      fprintf(handle, "@misc{ %s,\n",str_splice(title, author, year));
+      tmp = str_splice(title, author, year);
+      fprintf(handle, 
+	      "@misc{ %s,\n", 
+	      tmp);
+      free(tmp);      
       if ( title )
 	fprintf(handle, "    title = \"%s\"%s\n", title,
 	    (last == title)?"":",");
@@ -360,7 +414,10 @@ printSelectedKeywordsBibtex (FILE * handle,
       if ( pages )
 	fprintf(handle, "    pages = \"%s\"%s\n", pages,
 	    (last == pages)?"":",");
-
+      if (month != NULL)
+	free(month);
+      if (year != NULL)
+	free(year);
       fprintf(handle, "}\n\n");
     }
 }
@@ -383,13 +440,14 @@ main (int argc, char *argv[])
   char * libraries = NULL;
   char * hash = NULL;
   int splitKeywords = NO;
-  int verbose = NO;
+  int verbose = 0;
   int useFilename = NO;
   int nodefault = NO;
   int *print;
   int defaultAll = YES;
   int duplicates = EXTRACTOR_DUPLICATES_REMOVE_UNKNOWN;
   int bibtex = NO;
+  int grepfriendly = NO;
   char * binary = NULL;
   int ret = 0;
 
@@ -413,6 +471,7 @@ main (int argc, char *argv[])
 	{"bibtex", 0, 0, 'b'},
 	{"duplicates", 0, 0, 'd'},
 	{"filename", 0, 0, 'f'},
+	{"grep-friendly", 0, 0, 'g'},
 	{"help", 0, 0, 'h'},
 	{"hash", 1, 0, 'H'},
 	{"list", 0, 0, 'L'},
@@ -428,7 +487,7 @@ main (int argc, char *argv[])
       };
       option_index = 0;
       c = getopt_long (argc,
-		       argv, "vhbl:nsH:fp:x:LVdraB:",
+		       argv, "vhbgl:nsH:fp:x:LVdraB:",
 		       long_options,
 		       &option_index);
 
@@ -451,6 +510,9 @@ main (int argc, char *argv[])
 	case 'f':
 	  useFilename = YES;
 	  break;
+	case 'g':
+	  grepfriendly = YES;
+	  break;
 	case 'h':
 	  printHelp();
 	  return 0;
@@ -463,7 +525,7 @@ main (int argc, char *argv[])
 	case 'L':
 	  i = 0;
 	  while (NULL != EXTRACTOR_getKeywordTypeAsString (i))
-	    printf ("%s\n", 
+	    printf ("%s\n",
 		    _(EXTRACTOR_getKeywordTypeAsString (i++)));
 	  return 0;
 	case 'n':
@@ -488,7 +550,7 @@ main (int argc, char *argv[])
 	    {
 	      if ( (0 == strcmp (optarg, EXTRACTOR_getKeywordTypeAsString (i))) ||
 		   (0 == strcmp (optarg, _(EXTRACTOR_getKeywordTypeAsString (i)))) )
-		   
+		
 		{
 		  print[i] = YES;
 		  break;
@@ -514,7 +576,7 @@ main (int argc, char *argv[])
 	  printf ("extract v%s\n", PACKAGE_VERSION);
 	  return 0;
 	case 'V':
-	  verbose = YES;
+	  verbose++;
 	  break;
 	case 'x':
 	  i = 0;
@@ -602,8 +664,8 @@ main (int argc, char *argv[])
     errno = 0;
     keywords = EXTRACTOR_getKeywords (extractors, argv[i]);
     if (0 != errno) {
-      if (verbose == YES) {
-	fprintf(stderr, 
+      if (verbose > 0) {
+	fprintf(stderr,
 		"%s: %s: %s\n",
 		argv[0], argv[i], strerror(errno));
       }
@@ -612,13 +674,21 @@ main (int argc, char *argv[])
     }
     if ( (duplicates != -1) || (bibtex == YES))
       keywords = EXTRACTOR_removeDuplicateKeywords (keywords, duplicates);
-    if (verbose == YES && bibtex == NO)
-      printf (_("Keywords for file %s:\n"), argv[i]);
+    if ( (verbose > 0) 
+	 && (bibtex == NO) ) {
+      if (grepfriendly == YES)
+	printf ("%s ", argv[i]);
+      else
+	printf (_("Keywords for file %s:"),
+		argv[i]);
+    }
     if (bibtex == YES)
       printSelectedKeywordsBibtex (stdout, keywords, print, argv[i]);
+    else if (grepfriendly == YES)
+      printSelectedKeywordsGrepFriendly(stdout, keywords, print, verbose);
     else
       printSelectedKeywords (stdout, keywords, print, verbose);
-    if (verbose == YES && bibtex == NO)
+    if (verbose > 0 && bibtex == NO)
       printf ("\n");
     EXTRACTOR_freeKeywords (keywords);
   }
