@@ -35,7 +35,7 @@
 #include <zlib.h>
 #endif
 
-#define DEBUG 1
+#define DEBUG 0
 
 /**
  * The sources of keywords as strings.
@@ -147,7 +147,7 @@ static const char *keywordTypes[] = {
   gettext_noop("generator"),
   gettext_noop("character set"),
   gettext_noop("line count"), /* 105 */
-  gettext_noop("paragraph count"), 
+  gettext_noop("paragraph count"),
   gettext_noop("editing cycles"),
   gettext_noop("scale"),
   gettext_noop("manager"),
@@ -171,11 +171,13 @@ static const char *keywordTypes[] = {
   gettext_noop("song count"),
   gettext_noop("starting song"),
   gettext_noop("hardware dependency"),
+  gettext_noop("ripper"), /* 130 */
+  gettext_noop("filesize") /* 131 */,
   NULL,
 };
 
 /* the number of keyword types (for bounds-checking) */
-#define HIGHEST_TYPE_NUMBER 130
+#define HIGHEST_TYPE_NUMBER 132
 
 #ifdef HAVE_LIBOGG
 #if HAVE_VORBIS
@@ -211,6 +213,12 @@ static const char *keywordTypes[] = {
 #define OLESO ""
 #endif
 
+#if HAVE_MPEG2
+#define MPEGSO "libextractor_mpeg:"
+#else
+#define MPEGSO ""
+#endif 
+
 /* ATTN: order matters (for performance!) since
    mime-types can be used to avoid parsing once
    the type has been established! */
@@ -236,13 +244,14 @@ libextractor_tiff:\
 libextractor_zip:\
 libextractor_rpm:\
 libextractor_riff:\
-libextractor_mpeg:\
 libextractor_elf:\
 libextractor_oo:\
 libextractor_asf:\
+libextractor_sid:\
+libextractor_nsfe:\
 libextractor_nsf"
 
-#define DEFAULT_LIBRARIES EXSO OLESO OGGSO QTSO DEFSO
+#define DEFAULT_LIBRARIES MPEGSO EXSO OLESO OGGSO QTSO DEFSO
 
 const char * EXTRACTOR_getDefaultLibraries() {
   return DEFAULT_LIBRARIES;
@@ -297,7 +306,7 @@ static char * cut_lib(char * in) {
  * Note that this may fail if LE is installed in one directory
  * and the binary linking against it sits elsewhere.
  */
-static char * 
+static char *
 get_path_from_proc_exe() {
   char fn[64];
   char line[1024];
@@ -306,7 +315,7 @@ get_path_from_proc_exe() {
   size_t size;
   FILE * f;
 
-  snprintf(fn, 
+  snprintf(fn,
 	   64,
 	   "/proc/%u/maps",
 	   getpid());
@@ -321,11 +330,11 @@ get_path_from_proc_exe() {
 	strstr(dir, "libextractor")[0] = '\0';
 	fclose(f);
 	return cut_lib(strdup(dir));
-      }      
+      }
     }
   }
   fclose(f);
-  snprintf(fn, 
+  snprintf(fn,
 	   64,
 	   "/proc/%u/exe",
 	   getpid());
@@ -357,16 +366,16 @@ get_path_from_proc_exe() {
 static char * get_path_from_module_filename() {
   char * path;
   char * idx;
-  
-  path = MALLOC(4097);
+
+  path = malloc(4097);
   GetModuleFileName(NULL, path, 4096);
-  idx = path + strlen(idx);
-  while ( (idx > path) && 
+  idx = path + strlen(path);
+  while ( (idx > path) &&
 	  (path != '\\') &&
 	  (path != '/') )
-    idx++;
+    idx--;
   *idx = '\0';
-  return cut_bin(path);  
+  return cut_bin(path);
 }
 #endif
 
@@ -374,7 +383,7 @@ static char * get_path_from_module_filename() {
  * This may also fail -- for example, if extract
  * is not also installed.
  */
-static char * 
+static char *
 get_path_from_PATH() {
   struct stat sbuf;
   char * path;
@@ -415,7 +424,7 @@ get_path_from_PATH() {
   return NULL;
 }
 
-static char * 
+static char *
 get_path_from_ENV_PREFIX() {
   const char * p;
 
@@ -435,7 +444,7 @@ static char * os_get_installation_path() {
   char * lpref;
   char * pexe;
   char * modu;
-  char * path;  
+  char * path;
 
   lpref = get_path_from_ENV_PREFIX();
 #if LINUX
@@ -526,7 +535,7 @@ void __attribute__ ((constructor)) le_ltdl_init() {
       strcat(cpath, ":");
       strcat(cpath, path);
       lt_dlsetsearchpath(cpath);
-      free(path);  
+      free(path);
       free(cpath);
     } else {
       lt_dlsetsearchpath(path);
@@ -1012,7 +1021,7 @@ getKeywords (EXTRACTOR_ExtractorList * extractor,
     memset(&strm,
 	   0,
 	   sizeof(z_stream));
-#ifdef ZLIB_VERNUM 
+#ifdef ZLIB_VERNUM
     gzip_header_length = 0;
 #endif
     if (size > gzip_header_length) {
@@ -1026,14 +1035,14 @@ getKeywords (EXTRACTOR_ExtractorList * extractor,
     strm.zalloc = NULL;
     strm.zfree = NULL;
     strm.opaque = NULL;
-    
+
     /*
      * note: maybe plain inflateInit(&strm) is adequate,
      * it looks more backward-compatible also ;
      *
      * ZLIB_VERNUM isn't defined by zlib version 1.1.4 ;
      * there might be a better check.
-     */ 
+     */
 #ifdef ZLIB_VERNUM
     if (Z_OK == inflateInit2(&strm,
 			     15 + 32)) {
@@ -1070,9 +1079,9 @@ getKeywords (EXTRACTOR_ExtractorList * extractor,
 	    free(buf);
 	    buf = NULL;
 	  }
-	} while ( (buf != NULL) &&		  
-		  (ret != Z_STREAM_END) );      
-	dsize = pos + strm.total_out; 
+	} while ( (buf != NULL) &&		
+		  (ret != Z_STREAM_END) );
+	dsize = pos + strm.total_out;
 	inflateEnd(&strm);
 	if (dsize == 0) {
 	  free(buf);
@@ -1084,7 +1093,8 @@ getKeywords (EXTRACTOR_ExtractorList * extractor,
 #endif
 
 #if HAVE_LIBBZ2
-  if ( (data[0] == 'B') &&
+  if ( (size >= 4) &&
+       (data[0] == 'B') &&
        (data[1] == 'Z') &&
        (data[2] == 'h') ) {
     /* now try bz2 decompression */
@@ -1115,7 +1125,7 @@ getKeywords (EXTRACTOR_ExtractorList * extractor,
 	do {
 	  bret = BZ2_bzDecompress(&bstrm);
 	  if (bret == Z_OK) {
-	    if (dsize == MAX_DECOMPRESS) 
+	    if (dsize == MAX_DECOMPRESS)
 	      break;
 	    bpos += bstrm.total_out_lo32;
 	    bstrm.total_out_lo32 = 0;
@@ -1131,8 +1141,8 @@ getKeywords (EXTRACTOR_ExtractorList * extractor,
 	    buf = NULL;
 	  }
 	} while ( (buf != NULL) &&
-		  (bret != BZ_STREAM_END) );      
-	dsize = bpos + bstrm.total_out_lo32; 
+		  (bret != BZ_STREAM_END) );
+	dsize = bpos + bstrm.total_out_lo32;
 	BZ2_bzDecompressEnd(&bstrm);
 	if (dsize == 0) {
 	  free(buf);
@@ -1178,40 +1188,56 @@ EXTRACTOR_getKeywords (EXTRACTOR_ExtractorList * extractor,
   void * buffer;
   struct stat fstatbuf;
   size_t size;
-  int eno;
+  int eno, dir;
 
+  if (-1 == STAT(filename, &fstatbuf))
+    return NULL;
+
+  if (!S_ISDIR(fstatbuf.st_mode)) {
+    dir = 0;
+      
 #ifdef O_LARGEFILE
-  file = fileopen(filename, O_RDONLY | O_LARGEFILE);
+    file = fileopen(filename, O_RDONLY | O_LARGEFILE);
 #else
-  file = fileopen(filename, O_RDONLY);
+    file = fileopen(filename, O_RDONLY);
 #endif
-  if (-1 == file)
-    return NULL;
-  if (-1 == FSTAT(file, &fstatbuf)) {
-    close(file);
-    return NULL;
+    if (-1 == file)
+      return NULL;
+  
+    size = fstatbuf.st_size;
+    if (size == 0) {
+      close(file);
+      return NULL;
+    }
+  
+    if (size > MAX_READ)
+      size = MAX_READ; /* do not mmap/read more than 1 GB! */
+    buffer = MMAP(NULL, size, PROT_READ, MAP_PRIVATE, file, 0);
+    if ( (buffer == NULL) || (buffer == (void *) -1) ) {
+      eno = errno;
+      close(file);
+      errno = eno;
+      return NULL;
+    }
   }
-  size = fstatbuf.st_size;
-  if (size == 0) {
-    close(file);
-    return NULL;
-  }
-
-  if (size > MAX_READ)
-    size = MAX_READ; /* do not mmap/read more than 1 GB! */
-  buffer = MMAP(NULL, size, PROT_READ, MAP_PRIVATE, file, 0);
-  if ( (buffer == NULL) || (buffer == (void *) -1) ) {
-    eno = errno;
-    close(file);
-    errno = eno;
-    return NULL;
+  else {
+    dir = 1;
+    
+    size = 0;
+    buffer = malloc(1);
   }
+  
   result = getKeywords(extractor,
 		       filename,
 		       buffer,
 		       size);
-  MUNMAP (buffer, size);
-  close(file);
+  
+  if (dir)
+    free(buffer);
+  else {
+    MUNMAP (buffer, size);
+    close(file);
+  }
   return result;
 }
 
@@ -1244,8 +1270,7 @@ removeKeyword (const char *keyword,
 	       const EXTRACTOR_KeywordType type,
 	       const unsigned int options,
 	       EXTRACTOR_KeywordList ** list,
-	       EXTRACTOR_KeywordList * current)
-{
+	       EXTRACTOR_KeywordList * current) {
   EXTRACTOR_KeywordList *first;
   EXTRACTOR_KeywordList *pos;
   EXTRACTOR_KeywordList *prev;
@@ -1254,37 +1279,34 @@ removeKeyword (const char *keyword,
   first = *list;
   pos = first;
   prev = NULL;
-  while (pos != NULL)
-    {
-      if (pos == current)
-	{
-	  prev = pos;
-	  pos = current->next;
-	}
-      if (pos == NULL)
-	break;
-      if ( (0 == strcmp (pos->keyword, keyword)) &&
-	   ( (pos->keywordType == type) ||
-	     (((options & EXTRACTOR_DUPLICATES_TYPELESS) > 0)) ||
-	     ( ((options & EXTRACTOR_DUPLICATES_REMOVE_UNKNOWN) > 0) &&
-	       (pos->keywordType == EXTRACTOR_UNKNOWN)) ) )
-	{
-	  /* remove! */
-	  if (prev == NULL)
-	    first = pos->next;
-	  else
-	    prev->next = pos->next;
-	  next = pos->next;
-	  free (pos->keyword);
-	  free (pos);
-	  pos = next;
-	}
+  while (pos != NULL) {
+    if (pos == current) {
+      prev = pos;
+      pos = current->next;
+    }
+    if (pos == NULL)
+      break;
+    if ( (0 == strcmp (pos->keyword, keyword)) &&
+	 ( (pos->keywordType == type) ||
+	   ( ((options & EXTRACTOR_DUPLICATES_TYPELESS) > 0) &&
+	     ( (pos->keywordType == EXTRACTOR_SPLIT) ||
+	       (type != EXTRACTOR_SPLIT)) ) ||
+	   ( ((options & EXTRACTOR_DUPLICATES_REMOVE_UNKNOWN) > 0) &&
+	     (pos->keywordType == EXTRACTOR_UNKNOWN)) ) ) {
+      /* remove! */
+      if (prev == NULL)
+	first = pos->next;
       else
-	{
-	  prev = pos;
-	  pos = pos->next;
-	}
-    }				/* end while */
+	prev->next = pos->next;
+      next = pos->next;
+      free (pos->keyword);
+      free (pos);
+      pos = next;
+    } else {
+      prev = pos;
+      pos = pos->next;
+    }
+  } /* end while */
   *list = first;
 }
 
@@ -1301,9 +1323,9 @@ EXTRACTOR_removeDuplicateKeywords (EXTRACTOR_KeywordList * list,
 
   pos = list;
   while (pos != NULL) {
-    removeKeyword(pos->keyword, 
+    removeKeyword(pos->keyword,
 		  pos->keywordType,
-		  options, 
+		  options,
 		  &list,
 		  pos);
     pos = pos->next;
