@@ -33,7 +33,7 @@ static void addKeyword(struct EXTRACTOR_Keywords ** list,
 }
 
 /* convert other keywords to lower case */
-struct EXTRACTOR_Keywords * 
+struct EXTRACTOR_Keywords *
 libextractor_lower_extract(char * filename,
 			   char * data,
 			   size_t size,
@@ -43,15 +43,20 @@ libextractor_lower_extract(char * filename,
   unsigned int mem, needed, i;
 
   pos = prev;
-  lower = 0;
+  lower = NULL;
   mem = 0;
 
   while (pos != NULL)
   {
+    if (pos->keywordType == EXTRACTOR_FILE_SIZE) {
+      pos = pos->next;
+      continue;
+    }
+    
     needed = strlen(pos->keyword) + 1;
     if (needed > mem)
     {
-     lower = (char *) (lower) ? realloc(lower, needed) : malloc(needed);
+     lower = (lower == NULL) ? realloc(lower, needed) : malloc(needed);
      mem = needed;
     }
 
