@@ -123,14 +123,14 @@ int main(int argc,
   memset(&line[0], 0, 2048);
   fscanf(dictin, "%s", (char*)&line);
   charset = strdup(line); /* not used (yet) */
-  while (1 == fscanf(dictin, "%s", (char*)&line)) {    
+  while (1 == fscanf(dictin, "%s", (char*)&line)) {
     words[cnt] = strdup(line);
     cnt++;
     memset(&line[0], 0, 2048);
-    if (cnt > ALLOCSIZE) {
+    if (cnt >= ALLOCSIZE) {
       fprintf(stderr,
 	      _("Increase ALLOCSIZE (in %s).\n"),
-	      __FILE__);
+	      __FILE__);      
       exit(-1);
     }
   }
@@ -160,7 +160,7 @@ int main(int argc,
     FILE * btfile;
 
     snprintf(fn, 64, "%s_%d.c", argv[1], j);
-    btfile = fopen(fn, "w+");    
+    btfile = fopen(fn, "w+");
     if (btfile == NULL) {
       fprintf(stderr,
 	      _("Error opening file `%s': %s\n"),
@@ -206,5 +206,6 @@ int main(int argc,
 	  bn,
 	  ADDR_PER_ELEMENT,
 	  bf.bitArraySize);
+  free(charset);
   return 0;
 }
